==> process-kafka-quickstart-springboot-1.0.0.Final-sources.jar: org/kie/kogito/test/TravelersModel.java <==
package org.kie.kogito.test;

import java.util.Map;
import java.util.HashMap;

@org.kie.internal.kogito.codegen.Generated(value = "kogito-codegen", reference = "Travelers", name = "Travelers", hidden = false)
public class TravelersModel implements org.kie.kogito.Model {

    private String id;

    public void setId(String id) {
        this.id = id;
    }

    public String getId() {
        return this.id;
    }

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("traveller", this.traveller);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    @Override
    public void update(Map<String, Object> params) {
        fromMap(getId(), params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.id = id;
        this.traveller = (org.acme.travel.Traveller) params.get("traveller");
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "traveller")
    @javax.validation.Valid()
    private org.acme.travel.Traveller traveller;

    public org.acme.travel.Traveller getTraveller() {
        return traveller;
    }

    public void setTraveller(org.acme.travel.Traveller traveller) {
        this.traveller = traveller;
    }

    public TravelersModelOutput toOutput() {
        TravelersModelOutput result = new TravelersModelOutput();
        result.setId(getId());
        result.setTraveller(getTraveller());
        return result;
    }
}

==> process-kafka-quickstart-springboot-1.4.0.Final-sources.jar: org/kie/kogito/test/TravelersModel.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.kogito.test;

import java.util.Map;
import java.util.HashMap;

@org.kie.kogito.codegen.Generated(value = "kogito-codegen", reference = "Travelers", name = "Travelers", hidden = false)
public class TravelersModel implements org.kie.kogito.Model {

    private String id;

    public void setId(String id) {
        this.id = id;
    }

    public String getId() {
        return this.id;
    }

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("traveller", this.traveller);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    @Override
    public void update(Map<String, Object> params) {
        fromMap(getId(), params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.id = id;
        this.traveller = (org.acme.travel.Traveller) params.get("traveller");
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "traveller")
    @javax.validation.Valid()
    private org.acme.travel.Traveller traveller;

    public org.acme.travel.Traveller getTraveller() {
        return traveller;
    }

    public void setTraveller(org.acme.travel.Traveller traveller) {
        this.traveller = traveller;
    }

    public TravelersModelOutput toOutput() {
        TravelersModelOutput result = new TravelersModelOutput();
        result.setId(getId());
        result.setTraveller(getTraveller());
        return result;
    }
}
